<?php

namespace Litecms\Gallery\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Litecms\Gallery\Http\Requests\GalleryRequest;
use Litecms\Gallery\Models\Gallery;

/**
 * Admin web controller class.
 */
class GalleryWorkflowController extends BaseController
{

    /**
     * Workflow controller function for gallery.
     *
     * @param Model   $gallery
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(GalleryRequest $request, Gallery $gallery, $step)
    {

        try {

            $gallery->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('gallery::gallery.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/gallery/gallery/' . $gallery->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/gallery/gallery/' . $gallery->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for gallery.
     *
     * @param Model   $gallery
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
     */

    public function getWorkflow(Gallery $gallery, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $gallery->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('gallery::gallery.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('gallery::admin.gallery.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('gallery::admin.gallery.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('gallery::admin.gallery.message', $data)->render();

        }

    }
}
