<?php

namespace Litecms\Gallery\Workflow;

use Litecms\Gallery\Models\Gallery;
use Validator;

class GalleryValidator
{

    /**
     * Determine if the given gallery is valid for complete status.
     *
     * @param Gallery $gallery
     *
     * @return bool / Validator
     */
    public function complete(Gallery $gallery)
    {
        return Validator::make($gallery->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given gallery is valid for verify status.
     *
     * @param Gallery $gallery
     *
     * @return bool / Validator
     */
    public function verify(Gallery $gallery)
    {
        return Validator::make($gallery->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given gallery is valid for approve status.
     *
     * @param Gallery $gallery
     *
     * @return bool / Validator
     */
    public function approve(Gallery $gallery)
    {
        return Validator::make($gallery->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given gallery is valid for publish status.
     *
     * @param Gallery $gallery
     *
     * @return bool / Validator
     */
    public function publish(Gallery $gallery)
    {
        return Validator::make($gallery->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given gallery is valid for archive status.
     *
     * @param Gallery $gallery
     *
     * @return bool / Validator
     */
    public function archive(Gallery $gallery)
    {
        return Validator::make($gallery->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given gallery is valid for unpublish status.
     *
     * @param Gallery $gallery
     *
     * @return bool / Validator
     */
    public function unpublish(Gallery $gallery)
    {
        return Validator::make($gallery->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
